@@ -91,7 +91,7 @@ HD_DEFINE_PLUGIN_MODULE (CountdownHomeWidget, countdown_home_widget,
   HD_TYPE_HOME_PLUGIN_ITEM)
 
 gboolean countdown_home_widget_update_content (CountdownHomeWidget *self);
-//static gboolean countdown_home_widget_expose_button_area (GtkWidget *widget, GdkEventExpose *event, CountdownHomeWidget *self);
+static gboolean countdown_home_widget_expose_button_area (GtkWidget *widget, GdkEventExpose *event, CountdownHomeWidget *self);
 
 gboolean check_ampm_format ()
 {
@@ -819,7 +819,7 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
 	}
 	g_signal_connect (bgSettingsButton, "clicked", G_CALLBACK (countdown_home_widget_bg_settings), bgDialog);
 
-	//gtk_container_add (GTK_CONTAINER (content_area), bgSettingsButton);
+	gtk_container_add (GTK_CONTAINER (content_area), bgSettingsButton);
 	
 	hildon_button_set_value (HILDON_BUTTON (transSettingsButton), _("Change how terms display"));
 	g_signal_connect (transSettingsButton, "clicked", G_CALLBACK (countdown_home_widget_trans_settings), transDialog);
@@ -1220,13 +1220,13 @@ void countdown_home_widget_content_create (CountdownHomeWidget *self)
     gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), GTK_WIDGET (self->priv->contents), FALSE, FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (self->priv->homeWidget), align);
     gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), GTK_WIDGET (self->priv->buttons), FALSE, FALSE, 0);
-	
-	//g_signal_connect (self->priv->buttons, "expose-event", G_CALLBACK (countdown_home_widget_expose_button_area), self);
-	
+
 	self->priv->upButtonPressed = FALSE;
 	self->priv->downButtonPressed = FALSE;
 	self->priv->addButtonPressed = FALSE;
 	
+	g_signal_connect (self->priv->buttons, "expose-event", G_CALLBACK (countdown_home_widget_expose_button_area), self);
+	
 	self->priv->headImage = cairo_image_surface_create_from_png ("/etc/hildon/theme/images/RSSAppletHead.png");
 	self->priv->leftButtonImage = cairo_image_surface_create_from_png ("/etc/hildon/theme/images/RSSAppletLeftButton.png");
 	self->priv->leftButtonImagePressed = cairo_image_surface_create_from_png ("/etc/hildon/theme/images/RSSAppletLeftButtonPressed.png");
@@ -1234,7 +1234,8 @@ void countdown_home_widget_content_create (CountdownHomeWidget *self)
 	self->priv->centerButtonImagePressed = cairo_image_surface_create_from_png ("/etc/hildon/theme/images/RSSAppletCenterButtonPressed.png");
 	self->priv->rightButtonImage = cairo_image_surface_create_from_png ("/etc/hildon/theme/images/RSSAppletRightButton.png");
 	self->priv->rightButtonImagePressed = cairo_image_surface_create_from_png ("/etc/hildon/theme/images/RSSAppletRightButtonPressed.png");
-	
+
+
     gtk_widget_show_all (self->priv->homeWidget);
 }
 
@@ -1523,124 +1524,120 @@ static void countdown_home_widget_realize (GtkWidget *widget)
 	GTK_WIDGET_CLASS (countdown_home_widget_parent_class)->realize (widget);
 }
 
-/*static gboolean countdown_home_widget_expose_button_area (GtkWidget *widget, GdkEventExpose *event, CountdownHomeWidget *self)
+static gboolean countdown_home_widget_expose_button_area (GtkWidget *widget, GdkEventExpose *event, CountdownHomeWidget *self)
 {
-	cairo_t *cr;
+	if (!self->priv->systemBG) {
+		cairo_t *cr;
 
-    cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
-	gdk_cairo_region (cr, event->region);
-	cairo_clip (cr);
+		cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
+		gdk_cairo_region (cr, event->region);
+		cairo_clip (cr);
 
-    cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-	if (self->priv->systemBG) {
-		GdkColor color;
-		gtk_style_lookup_color (gtk_rc_get_style(widget), "DefaultBackgroundColor", &color);
-		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.8);
-	} else {
+		cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
 		GdkColor color;
 		gdk_color_parse (self->priv->buttonAreaColor, &color);
 		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65535.0, color.blue/65535.0, self->priv->buttonAreaOpacity/100.0);
-	}
     
-	gint width, height, x, y;
-	width = widget->allocation.width;
-	height = widget->allocation.height;
-	x = widget->allocation.x;
-	y = widget->allocation.y;
+		gint width, height, x, y;
+		width = widget->allocation.width;
+		height = widget->allocation.height;
+		x = widget->allocation.x;
+		y = widget->allocation.y;
 
-	cairo_move_to(cr, x + self->priv->radius, y);
-	cairo_line_to(cr, x + width, y);
-	cairo_line_to(cr, x + width, y + height - self->priv->radius);
-	cairo_curve_to(cr, x + width, y + height - self->priv->radius, x + width,
+		cairo_move_to(cr, x + self->priv->radius, y);
+		cairo_line_to(cr, x + width, y);
+		cairo_line_to(cr, x + width, y + height - self->priv->radius);
+		cairo_curve_to(cr, x + width, y + height - self->priv->radius, x + width,
 				y + height, x + width - self->priv->radius, y + height);
-	cairo_line_to(cr, x + self->priv->radius, y + height);
-	cairo_curve_to(cr, x + self->priv->radius, y + height, x, y + height, x,
+		cairo_line_to(cr, x + self->priv->radius, y + height);
+		cairo_curve_to(cr, x + self->priv->radius, y + height, x, y + height, x,
 				y + height - self->priv->radius);
-	cairo_line_to(cr, x, y);
-
-	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-
-	cairo_fill(cr);
-	
-	if (self->priv->addButtonPressed) {
-		GdkColor color;
-		gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
-		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
-		
-		gint width, height, x, y;
-		width = widget->allocation.width;
-		height = widget->allocation.height;
-		x = widget->allocation.x;
-		y = widget->allocation.y;
-
-		cairo_move_to(cr, x + self->priv->radius, y);
-		cairo_line_to(cr, x + width, y);
-		cairo_line_to(cr, x + width, y + height - self->priv->radius);
-		cairo_curve_to(cr, x + width, y + height - self->priv->radius, x + width,
-					y + height, x + width - self->priv->radius, y + height);
-		cairo_line_to(cr, x + self->priv->radius, y + height);
-		cairo_curve_to(cr, x + self->priv->radius, y + height, x, y + height, x,
-					y + height - self->priv->radius);
 		cairo_line_to(cr, x, y);
-	
+
 		cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-		cairo_fill (cr);
-	}
+
+		cairo_fill(cr);
 	
-	if (self->priv->upButtonPressed) {
-		GdkColor color;
-		gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
-		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
+		if (self->priv->addButtonPressed) {
+			GdkColor color;
+			gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
+			cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
 		
-		gint width, height, x, y;
-		width = widget->allocation.width;
-		height = widget->allocation.height;
-		x = widget->allocation.x;
-		y = widget->allocation.y;
+			gint width, height, x, y;
+			width = widget->allocation.width;
+			height = widget->allocation.height;
+			x = widget->allocation.x;
+			y = widget->allocation.y;
 
-		cairo_move_to(cr, x + self->priv->radius, y);
-		cairo_line_to(cr, x + width, y);
-		cairo_line_to(cr, x + width, y + height - self->priv->radius);
-		cairo_curve_to(cr, x + width, y + height - self->priv->radius, x + width,
+			cairo_move_to(cr, x + self->priv->radius, y);
+			cairo_line_to(cr, x + width, y);
+			cairo_line_to(cr, x + width, y + height - self->priv->radius);
+			cairo_curve_to(cr, x + width, y + height - self->priv->radius, x + width,
 					y + height, x + width - self->priv->radius, y + height);
-		cairo_line_to(cr, x + self->priv->radius, y + height);
-		cairo_curve_to(cr, x + self->priv->radius, y + height, x, y + height, x,
+			cairo_line_to(cr, x + self->priv->radius, y + height);
+			cairo_curve_to(cr, x + self->priv->radius, y + height, x, y + height, x,
 					y + height - self->priv->radius);
-		cairo_line_to(cr, x, y);
+			cairo_line_to(cr, x, y);
 	
-		cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-		cairo_fill (cr);
-	}
+			cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+			cairo_fill (cr);
+		}
 	
-	if (self->priv->downButtonPressed) {
-		GdkColor color;
-		gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
-		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
+		if (self->priv->upButtonPressed) {
+			GdkColor color;
+			gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
+			cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
 		
-		gint width, height, x, y;
-		width = widget->allocation.width;
-		height = widget->allocation.height;
-		x = widget->allocation.x;
-		y = widget->allocation.y;
+			gint width, height, x, y;
+			width = widget->allocation.width;
+			height = widget->allocation.height;
+			x = widget->allocation.x;
+			y = widget->allocation.y;
 
-		cairo_move_to(cr, x + self->priv->radius, y);
-		cairo_line_to(cr, x + width, y);
-		cairo_line_to(cr, x + width, y + height - self->priv->radius);
-		cairo_curve_to(cr, x + width, y + height - self->priv->radius, x + width,
+			cairo_move_to(cr, x + self->priv->radius, y);
+			cairo_line_to(cr, x + width, y);
+			cairo_line_to(cr, x + width, y + height - self->priv->radius);
+			cairo_curve_to(cr, x + width, y + height - self->priv->radius, x + width,
 					y + height, x + width - self->priv->radius, y + height);
-		cairo_line_to(cr, x + self->priv->radius, y + height);
-		cairo_curve_to(cr, x + self->priv->radius, y + height, x, y + height, x,
+			cairo_line_to(cr, x + self->priv->radius, y + height);
+			cairo_curve_to(cr, x + self->priv->radius, y + height, x, y + height, x,
 					y + height - self->priv->radius);
-		cairo_line_to(cr, x, y);
+			cairo_line_to(cr, x, y);
 	
-		cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-		cairo_fill (cr);
-	}
+			cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+			cairo_fill (cr);
+		}
+	
+		if (self->priv->downButtonPressed) {
+			GdkColor color;
+			gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
+			cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
+		
+			gint width, height, x, y;
+			width = widget->allocation.width;
+			height = widget->allocation.height;
+			x = widget->allocation.x;
+			y = widget->allocation.y;
 
-    cairo_destroy (cr);
+			cairo_move_to(cr, x + self->priv->radius, y);
+			cairo_line_to(cr, x + width, y);
+			cairo_line_to(cr, x + width, y + height - self->priv->radius);
+			cairo_curve_to(cr, x + width, y + height - self->priv->radius, x + width,
+					y + height, x + width - self->priv->radius, y + height);
+			cairo_line_to(cr, x + self->priv->radius, y + height);
+			cairo_curve_to(cr, x + self->priv->radius, y + height, x, y + height, x,
+					y + height - self->priv->radius);
+			cairo_line_to(cr, x, y);
+	
+			cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+			cairo_fill (cr);
+		}
+
+    	cairo_destroy (cr);
+	}
 	
 	return FALSE;
-}*/
+}
 
 static gboolean countdown_home_widget_expose_event (GtkWidget *widget, GdkEventExpose *event)
 {
@@ -1648,83 +1645,82 @@ static gboolean countdown_home_widget_expose_event (GtkWidget *widget, GdkEventE
 	CountdownHomeWidget *self = COUNTDOWN_HOME_WIDGET (widget);
 	cairo_t *cr;
 
-    cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
-    //cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-	cairo_set_source_surface (cr, self->priv->headImage, 0, 0);
-	cairo_paint (cr);
-    if (self->priv->eventPressed) {
-		gdk_cairo_region (cr, event->region);
-		cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-		GdkColor color;
-		gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
-		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65535.0, color.blue/65535.0, 0.8);
-		cairo_fill (cr);
-	}
-    cairo_destroy (cr);
-	
-    cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
-    //cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-    if (self->priv->upButtonPressed) {
-		cairo_set_source_surface (cr, self->priv->leftButtonImagePressed, 0, 312);
-	} else {
-		cairo_set_source_surface (cr, self->priv->leftButtonImage, 0, 312);
-	}
-    cairo_paint (cr);
-    cairo_destroy (cr);
-
-    cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
-    //cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-    if (self->priv->addButtonPressed) {
-		cairo_set_source_surface (cr, self->priv->centerButtonImagePressed, 108, 312);
-	} else {
-		cairo_set_source_surface (cr, self->priv->centerButtonImage, 108, 312);
-	}
-    cairo_paint (cr);
-    cairo_destroy (cr);
-    
-    cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
-    //cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-    if (self->priv->downButtonPressed) {
-		cairo_set_source_surface (cr, self->priv->rightButtonImagePressed, 208, 312);
-	} else {
-		cairo_set_source_surface (cr, self->priv->rightButtonImage, 208, 312);
-	}
-    cairo_paint (cr);
-    cairo_destroy (cr);
-	/*cr = gdk_cairo_create(GDK_DRAWABLE (widget->window));
-	if (self->priv->systemBG) {
-		GdkColor color;
-		gtk_style_lookup_color (gtk_rc_get_style(widget), "DefaultBackgroundColor", &color);
-		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.75);
-	} else {
+	if (!self->priv->systemBG) {
+		cr = gdk_cairo_create(GDK_DRAWABLE (widget->window));
 		GdkColor color;
 		gdk_color_parse (self->priv->bgColor, &color);
 		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65535.0, color.blue/65535.0, self->priv->bgOpacity/100.0);
-	}
 	
-	gint width, height, x, y;
-	width = widget->allocation.width;
-	height = widget->allocation.height;
-	x = widget->allocation.x;
-	y = widget->allocation.y;
+		gint width, height, x, y;
+		width = widget->allocation.width;
+		height = widget->allocation.height;
+		x = widget->allocation.x;
+		y = widget->allocation.y;
 
-	cairo_move_to(cr, x + self->priv->radius, y);
-	cairo_line_to(cr, x + width - self->priv->radius, y);
-	cairo_curve_to(cr, x + width - self->priv->radius, y, x + width, y, x + width,
+		cairo_move_to(cr, x + self->priv->radius, y);
+		cairo_line_to(cr, x + width - self->priv->radius, y);
+		cairo_curve_to(cr, x + width - self->priv->radius, y, x + width, y, x + width,
 				y + self->priv->radius);
-	cairo_line_to(cr, x + width, y + height - self->priv->radius);
-	cairo_curve_to(cr, x + width, y + height - self->priv->radius, x + width,
+		cairo_line_to(cr, x + width, y + height - self->priv->radius);
+		cairo_curve_to(cr, x + width, y + height - self->priv->radius, x + width,
 				y + height, x + width - self->priv->radius, y + height);
-	cairo_line_to(cr, x + self->priv->radius, y + height);
-	cairo_curve_to(cr, x + self->priv->radius, y + height, x, y + height, x,
+		cairo_line_to(cr, x + self->priv->radius, y + height);
+		cairo_curve_to(cr, x + self->priv->radius, y + height, x, y + height, x,
 				y + height - self->priv->radius);
-	cairo_line_to(cr, x, y + self->priv->radius);
-	cairo_curve_to(cr, x, y + self->priv->radius, x, y, x + self->priv->radius, y);
+		cairo_line_to(cr, x, y + self->priv->radius);
+		cairo_curve_to(cr, x, y + self->priv->radius, x, y, x + self->priv->radius, y);
 
-	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+		cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
 
-	cairo_fill(cr);
-	cairo_destroy(cr);*/
+		cairo_fill(cr);
+		cairo_destroy(cr);
+
+	} else {
+	
+	    cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
+    	//cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+		cairo_set_source_surface (cr, self->priv->headImage, 0, 0);
+		cairo_paint (cr);
+	    if (self->priv->eventPressed) {
+			gdk_cairo_region (cr, event->region);
+			cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+			GdkColor color;
+			gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
+			cairo_set_source_rgba (cr, color.red/65535.0, color.green/65535.0, color.blue/65535.0, 0.8);
+			cairo_fill (cr);
+		}
+	    cairo_destroy (cr);
+	
+    	cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
+	    //cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+    	if (self->priv->upButtonPressed) {
+			cairo_set_source_surface (cr, self->priv->leftButtonImagePressed, 0, 312);
+		} else {
+			cairo_set_source_surface (cr, self->priv->leftButtonImage, 0, 312);
+		}
+    	cairo_paint (cr);
+	    cairo_destroy (cr);
+
+    	cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
+	    //cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+    	if (self->priv->addButtonPressed) {
+			cairo_set_source_surface (cr, self->priv->centerButtonImagePressed, 108, 312);
+		} else {
+			cairo_set_source_surface (cr, self->priv->centerButtonImage, 108, 312);
+		}
+    	cairo_paint (cr);
+	    cairo_destroy (cr);
+    
+    	cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
+	    //cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+    	if (self->priv->downButtonPressed) {
+			cairo_set_source_surface (cr, self->priv->rightButtonImagePressed, 208, 312);
+		} else {
+			cairo_set_source_surface (cr, self->priv->rightButtonImage, 208, 312);
+		}
+    	cairo_paint (cr);
+	    cairo_destroy (cr);
+	}
 
 	return GTK_WIDGET_CLASS (countdown_home_widget_parent_class)->expose_event (widget, event);
 }
